shithub: pokecrystal

Download patch

ref: 5db892782adaa5bb5a3e4cd6fa06565764bd1fb0
parent: 99e66c25577e367d6c7ca75fea8b466b54c3317a
author: Rangi <remy.oukaour+rangi42@gmail.com>
date: Wed Dec 23 11:54:28 EST 2020

Remove "Buffer" suffix from two HRAM labels

--- a/engine/battle/core.asm
+++ b/engine/battle/core.asm
@@ -3063,7 +3063,7 @@
 	db "       @"
 
 SlideBattlePicOut:
-	ldh [hMapObjectIndexBuffer], a
+	ldh [hMapObjectIndex], a
 	ld c, a
 .loop
 	push bc
@@ -3086,7 +3086,7 @@
 	ret
 
 .DoFrame:
-	ldh a, [hMapObjectIndexBuffer]
+	ldh a, [hMapObjectIndex]
 	ld c, a
 	cp $8
 	jr nz, .back
@@ -9034,7 +9034,7 @@
 .LoadTrainerBackpicAsOAM:
 	ld hl, wVirtualOAMSprite00
 	xor a
-	ldh [hMapObjectIndexBuffer], a
+	ldh [hMapObjectIndex], a
 	ld b, 6
 	ld e, (SCREEN_WIDTH + 1) * TILE_WIDTH
 .outer_loop
@@ -9045,10 +9045,10 @@
 	inc hl
 	ld [hl], e ; x
 	inc hl
-	ldh a, [hMapObjectIndexBuffer]
+	ldh a, [hMapObjectIndex]
 	ld [hli], a ; tile id
 	inc a
-	ldh [hMapObjectIndexBuffer], a
+	ldh [hMapObjectIndex], a
 	ld a, PAL_BATTLE_OB_PLAYER
 	ld [hli], a ; attributes
 	ld a, d
@@ -9056,9 +9056,9 @@
 	ld d, a
 	dec c
 	jr nz, .inner_loop
-	ldh a, [hMapObjectIndexBuffer]
+	ldh a, [hMapObjectIndex]
 	add $3
-	ldh [hMapObjectIndexBuffer], a
+	ldh [hMapObjectIndex], a
 	ld a, e
 	add 1 * TILE_WIDTH
 	ld e, a
--- a/engine/events/overworld.asm
+++ b/engine/events/overworld.asm
@@ -1339,7 +1339,7 @@
 	farcall CheckFacingObject
 	jr nc, .fail
 
-	ldh a, [hObjectStructIndexBuffer]
+	ldh a, [hObjectStructIndex]
 	call GetObjectStruct
 	ld hl, OBJECT_MAP_OBJECT_INDEX
 	add hl, bc
--- a/engine/gfx/mon_icons.asm
+++ b/engine/gfx/mon_icons.asm
@@ -51,7 +51,7 @@
 
 .GetPartyMonItemGFX:
 	push bc
-	ldh a, [hObjectStructIndexBuffer]
+	ldh a, [hObjectStructIndex]
 	ld hl, wPartyMon1Item
 	ld bc, PARTYMON_STRUCT_LENGTH
 	call AddNTimes
@@ -125,7 +125,7 @@
 
 .SpawnItemIcon:
 	push bc
-	ldh a, [hObjectStructIndexBuffer]
+	ldh a, [hObjectStructIndex]
 	ld hl, wPartyMon1Item
 	ld bc, PARTYMON_STRUCT_LENGTH
 	call AddNTimes
@@ -154,7 +154,7 @@
 InitPartyMenuIcon:
 	ld a, [wCurIconTile]
 	push af
-	ldh a, [hObjectStructIndexBuffer]
+	ldh a, [hObjectStructIndex]
 	ld hl, wPartySpecies
 	ld e, a
 	ld d, 0
@@ -163,7 +163,7 @@
 	call ReadMonMenuIcon
 	ld [wCurIcon], a
 	call GetMemIconGFX
-	ldh a, [hObjectStructIndexBuffer]
+	ldh a, [hObjectStructIndex]
 ; y coord
 	add a
 	add a
@@ -184,7 +184,7 @@
 
 SetPartyMonIconAnimSpeed:
 	push bc
-	ldh a, [hObjectStructIndexBuffer]
+	ldh a, [hObjectStructIndex]
 	ld b, a
 	call .getspeed
 	ld a, b
--- a/engine/overworld/cmd_queue.asm
+++ b/engine/overworld/cmd_queue.asm
@@ -14,7 +14,7 @@
 	ld hl, wCmdQueue
 	xor a
 .loop
-	ldh [hMapObjectIndexBuffer], a
+	ldh [hMapObjectIndex], a
 	ld a, [hl]
 	and a
 	jr z, .skip
@@ -27,7 +27,7 @@
 .skip
 	ld de, CMDQUEUE_ENTRY_SIZE
 	add hl, de
-	ldh a, [hMapObjectIndexBuffer]
+	ldh a, [hMapObjectIndex]
 	inc a
 	cp CMDQUEUE_CAPACITY
 	jr nz, .loop
--- a/engine/overworld/events.asm
+++ b/engine/overworld/events.asm
@@ -540,7 +540,7 @@
 
 .IsObject:
 	call PlayTalkObject
-	ldh a, [hObjectStructIndexBuffer]
+	ldh a, [hObjectStructIndex]
 	call GetObjectStruct
 	ld hl, OBJECT_MAP_OBJECT_INDEX
 	add hl, bc
--- a/engine/overworld/map_objects.asm
+++ b/engine/overworld/map_objects.asm
@@ -1040,7 +1040,7 @@
 	add hl, bc
 	ld [hl], OBJECT_ACTION_STEP
 	ld hl, wCenteredObject
-	ldh a, [hMapObjectIndexBuffer]
+	ldh a, [hMapObjectIndex]
 	cp [hl]
 	jr z, .centered
 	ld hl, OBJECT_STEP_TYPE
@@ -1945,7 +1945,7 @@
 	ret z
 	ld a, [wObjectFollow_Leader]
 	ld d, a
-	ldh a, [hMapObjectIndexBuffer]
+	ldh a, [hMapObjectIndex]
 	cp d
 	ret nz
 	ld a, e
@@ -2085,7 +2085,7 @@
 
 DespawnEmote:
 	push bc
-	ldh a, [hMapObjectIndexBuffer]
+	ldh a, [hMapObjectIndex]
 	ld c, a
 	call .DeleteEmote
 	pop bc
@@ -2130,7 +2130,7 @@
 
 CopyTempObjectData:
 ; load into wTempObjectCopy:
-; -1, -1, [de], [de + 1], [de + 2], [hMapObjectIndexBuffer], [NextMapX], [NextMapY], -1
+; -1, -1, [de], [de + 1], [de + 2], [hMapObjectIndex], [NextMapX], [NextMapY], -1
 ; This spawns the object at the same place as whichever object is loaded into bc.
 	ld hl, wTempObjectCopyMapObjectIndex
 	ld [hl], -1
@@ -2145,7 +2145,7 @@
 	ld [hli], a
 	ld a, [de]
 	ld [hli], a
-	ldh a, [hMapObjectIndexBuffer]
+	ldh a, [hMapObjectIndex]
 	ld [hli], a
 	push hl
 	ld hl, OBJECT_NEXT_MAP_X
@@ -2169,7 +2169,7 @@
 	ld bc, wObjectStructs
 	xor a
 .loop
-	ldh [hMapObjectIndexBuffer], a
+	ldh [hMapObjectIndex], a
 	call DoesObjectHaveASprite
 	jr z, .ok
 	call UpdateObjectFrozen
@@ -2178,7 +2178,7 @@
 	add hl, bc
 	ld b, h
 	ld c, l
-	ldh a, [hMapObjectIndexBuffer]
+	ldh a, [hMapObjectIndex]
 	inc a
 	cp NUM_OBJECT_STRUCTS
 	jr nz, .loop
@@ -2228,13 +2228,13 @@
 	xor a
 	ld bc, wObjectStructs
 .loop
-	ldh [hMapObjectIndexBuffer], a
+	ldh [hMapObjectIndex], a
 	call SetFacing_Standing
 	ld hl, OBJECT_LENGTH
 	add hl, bc
 	ld b, h
 	ld c, l
-	ldh a, [hMapObjectIndexBuffer]
+	ldh a, [hMapObjectIndex]
 	inc a
 	cp NUM_OBJECT_STRUCTS
 	jr nz, .loop
@@ -2452,7 +2452,7 @@
 	ld bc, wObjectStructs
 	xor a
 .loop
-	ldh [hMapObjectIndexBuffer], a
+	ldh [hMapObjectIndex], a
 	call DoesObjectHaveASprite
 	jr z, .next
 	call HandleObjectStep
@@ -2461,7 +2461,7 @@
 	add hl, bc
 	ld b, h
 	ld c, l
-	ldh a, [hMapObjectIndexBuffer]
+	ldh a, [hMapObjectIndex]
 	inc a
 	cp NUM_OBJECT_STRUCTS
 	jr nz, .loop
@@ -2545,7 +2545,7 @@
 SetLeaderIfVisible:
 	call CheckObjectVisibility
 	ret c
-	ldh a, [hObjectStructIndexBuffer]
+	ldh a, [hObjectStructIndex]
 	ld [wObjectFollow_Leader], a
 	ret
 
@@ -2571,7 +2571,7 @@
 	ld hl, OBJECT_STEP_TYPE
 	add hl, bc
 	ld [hl], STEP_TYPE_RESET
-	ldh a, [hObjectStructIndexBuffer]
+	ldh a, [hObjectStructIndex]
 	ld [wObjectFollow_Follower], a
 	ret
 
--- a/engine/overworld/movement.asm
+++ b/engine/overworld/movement.asm
@@ -237,7 +237,7 @@
 Movement_remove_object:
 	call DeleteMapObject
 	ld hl, wObjectFollow_Leader
-	ldh a, [hMapObjectIndexBuffer]
+	ldh a, [hMapObjectIndex]
 	cp [hl]
 	jr nz, .not_leading
 	ld [hl], -1
@@ -680,7 +680,7 @@
 
 .skip_grass
 	ld hl, wCenteredObject
-	ldh a, [hMapObjectIndexBuffer]
+	ldh a, [hMapObjectIndex]
 	cp [hl]
 	jr z, .player
 
@@ -704,7 +704,7 @@
 	ld [hl], OBJECT_ACTION_SPIN
 
 	ld hl, wCenteredObject
-	ldh a, [hMapObjectIndexBuffer]
+	ldh a, [hMapObjectIndex]
 	cp [hl]
 	jr z, .player
 
@@ -728,7 +728,7 @@
 	ld [hl], OBJECT_ACTION_STAND
 
 	ld hl, wCenteredObject
-	ldh a, [hMapObjectIndexBuffer]
+	ldh a, [hMapObjectIndex]
 	cp [hl]
 	jr z, .player
 
@@ -760,7 +760,7 @@
 	call SpawnShadow
 
 	ld hl, wCenteredObject
-	ldh a, [hMapObjectIndexBuffer]
+	ldh a, [hMapObjectIndex]
 	cp [hl]
 	jr z, .player
 
--- a/engine/overworld/npc_movement.asm
+++ b/engine/overworld/npc_movement.asm
@@ -250,7 +250,7 @@
 .not_counter
 	ld bc, wObjectStructs ; redundant
 	ld a, 0
-	ldh [hMapObjectIndexBuffer], a
+	ldh [hMapObjectIndex], a
 	call IsNPCAtCoord
 	ret nc
 	ld hl, OBJECT_DIRECTION_WALKING
@@ -275,7 +275,7 @@
 	jr IsNPCAtCoord
 
 IsObjectFacingSomeoneElse: ; unreferenced
-	ldh a, [hMapObjectIndexBuffer]
+	ldh a, [hMapObjectIndex]
 	call GetObjectStruct
 	call .GetFacingCoords
 	call IsNPCAtCoord
@@ -315,7 +315,7 @@
 	ld bc, wObjectStructs
 	xor a
 .loop
-	ldh [hObjectStructIndexBuffer], a
+	ldh [hObjectStructIndex], a
 	call DoesObjectHaveASprite
 	jr z, .next
 
@@ -345,9 +345,9 @@
 	jr nz, .check_current_coords
 
 .continue
-	ldh a, [hMapObjectIndexBuffer]
+	ldh a, [hMapObjectIndex]
 	ld l, a
-	ldh a, [hObjectStructIndexBuffer]
+	ldh a, [hObjectStructIndex]
 	cp l
 	jr nz, .yes
 
@@ -362,9 +362,9 @@
 	ld a, [hl]
 	cp e
 	jr nz, .next
-	ldh a, [hMapObjectIndexBuffer]
+	ldh a, [hMapObjectIndex]
 	ld l, a
-	ldh a, [hObjectStructIndexBuffer]
+	ldh a, [hObjectStructIndex]
 	cp l
 	jr nz, .yes
 
@@ -373,7 +373,7 @@
 	add hl, bc
 	ld b, h
 	ld c, l
-	ldh a, [hObjectStructIndexBuffer]
+	ldh a, [hObjectStructIndex]
 	inc a
 	cp NUM_OBJECT_STRUCTS
 	jr nz, .loop
@@ -481,7 +481,7 @@
 	ld bc, wObjectStructs
 	xor a
 .loop
-	ldh [hObjectStructIndexBuffer], a
+	ldh [hObjectStructIndex], a
 	call DoesObjectHaveASprite
 	jr z, .next
 
@@ -505,7 +505,7 @@
 	ld a, [hl]
 	cp d
 	jr nz, .check_current_coords
-	ldh a, [hObjectStructIndexBuffer]
+	ldh a, [hObjectStructIndex]
 	cp PLAYER_OBJECT
 	jr z, .next
 	jr .yes
@@ -528,7 +528,7 @@
 	add hl, bc
 	ld b, h
 	ld c, l
-	ldh a, [hObjectStructIndexBuffer]
+	ldh a, [hObjectStructIndex]
 	inc a
 	cp NUM_OBJECT_STRUCTS
 	jr nz, .loop
--- a/engine/overworld/player_movement.asm
+++ b/engine/overworld/player_movement.asm
@@ -621,7 +621,7 @@
 ; Returns 1 if there is no NPC in front
 ; Returns 2 if there is a movable NPC in front
 	ld a, 0
-	ldh [hMapObjectIndexBuffer], a
+	ldh [hMapObjectIndex], a
 ; Load the next X coordinate into d
 	ld a, [wPlayerStandingMapX]
 	ld d, a
--- a/engine/overworld/player_object.asm
+++ b/engine/overworld/player_object.asm
@@ -41,10 +41,10 @@
 .ok
 	ld [hl], e
 	ld a, PLAYER_OBJECT
-	ldh [hMapObjectIndexBuffer], a
+	ldh [hMapObjectIndex], a
 	ld bc, wMapObjects
 	ld a, PLAYER_OBJECT
-	ldh [hObjectStructIndexBuffer], a
+	ldh [hObjectStructIndex], a
 	ld de, wObjectStructs
 	call CopyMapObjectToObjectStruct
 	ld a, PLAYER
@@ -94,7 +94,7 @@
 	ld hl, OBJECT_NEXT_MAP_Y
 	add hl, bc
 	ld e, [hl]
-	ldh a, [hMapObjectIndexBuffer]
+	ldh a, [hMapObjectIndex]
 	ld b, a
 	call CopyDECoordsToMapObject
 	and a
@@ -138,12 +138,12 @@
 	ld a, 1
 	ld de, OBJECT_LENGTH
 .loop
-	ldh [hObjectStructIndexBuffer], a
+	ldh [hObjectStructIndex], a
 	ld a, [hl]
 	and a
 	jr z, .done
 	add hl, de
-	ldh a, [hObjectStructIndexBuffer]
+	ldh a, [hObjectStructIndex]
 	inc a
 	cp NUM_OBJECT_STRUCTS
 	jr nz, .loop
@@ -169,12 +169,12 @@
 	ret
 
 .CopyMapObjectToTempObject:
-	ldh a, [hObjectStructIndexBuffer]
+	ldh a, [hObjectStructIndex]
 	ld hl, MAPOBJECT_OBJECT_STRUCT_ID
 	add hl, bc
 	ld [hl], a
 
-	ldh a, [hMapObjectIndexBuffer]
+	ldh a, [hMapObjectIndex]
 	ld [wTempObjectCopyMapObjectIndex], a
 
 	ld hl, MAPOBJECT_SPRITE
@@ -229,7 +229,7 @@
 	ld bc, wMap1Object
 	ld a, 1
 .loop
-	ldh [hMapObjectIndexBuffer], a
+	ldh [hMapObjectIndex], a
 	ld hl, MAPOBJECT_SPRITE
 	add hl, bc
 	ld a, [hl]
@@ -277,7 +277,7 @@
 	add hl, bc
 	ld b, h
 	ld c, l
-	ldh a, [hMapObjectIndexBuffer]
+	ldh a, [hMapObjectIndex]
 	inc a
 	cp NUM_OBJECTS
 	jr nz, .loop
@@ -316,7 +316,7 @@
 	ld bc, wMap1Object
 	ld a, 1
 .loop_v
-	ldh [hMapObjectIndexBuffer], a
+	ldh [hMapObjectIndex], a
 	ld hl, MAPOBJECT_SPRITE
 	add hl, bc
 	ld a, [hl]
@@ -351,7 +351,7 @@
 	add hl, bc
 	ld b, h
 	ld c, l
-	ldh a, [hMapObjectIndexBuffer]
+	ldh a, [hMapObjectIndex]
 	inc a
 	cp NUM_OBJECTS
 	jr nz, .loop_v
@@ -372,7 +372,7 @@
 	ld bc, wMap1Object
 	ld a, 1
 .loop_h
-	ldh [hMapObjectIndexBuffer], a
+	ldh [hMapObjectIndex], a
 	ld hl, MAPOBJECT_SPRITE
 	add hl, bc
 	ld a, [hl]
@@ -407,7 +407,7 @@
 	add hl, bc
 	ld b, h
 	ld c, l
-	ldh a, [hMapObjectIndexBuffer]
+	ldh a, [hMapObjectIndex]
 	inc a
 	cp NUM_OBJECTS
 	jr nz, .loop_h
@@ -680,7 +680,7 @@
 	ld hl, OBJECT_SPRITE_Y
 	add hl, de
 	ld [hl], a
-	ldh a, [hObjectStructIndexBuffer]
+	ldh a, [hObjectStructIndex]
 	ld hl, OBJECT_RANGE
 	add hl, de
 	ld [hl], a
--- a/engine/overworld/scripting.asm
+++ b/engine/overworld/scripting.asm
@@ -962,7 +962,7 @@
 	call GetScriptByte
 	call GetScriptObject
 	call UnmaskCopyMapObjectStruct
-	ldh a, [hMapObjectIndexBuffer]
+	ldh a, [hMapObjectIndex]
 	ld b, 0 ; clear
 	call ApplyEventActionAppearDisappear
 	ret
@@ -975,7 +975,7 @@
 	ldh a, [hLastTalked]
 .ok
 	call DeleteObjectStruct
-	ldh a, [hMapObjectIndexBuffer]
+	ldh a, [hMapObjectIndex]
 	ld b, 1 ; set
 	call ApplyEventActionAppearDisappear
 	farcall _UpdateSprites
--- a/engine/pokemon/party_menu.asm
+++ b/engine/pokemon/party_menu.asm
@@ -590,7 +590,7 @@
 	ret z
 	ld c, a
 	xor a
-	ldh [hObjectStructIndexBuffer], a
+	ldh [hObjectStructIndex], a
 .loop
 	push bc
 	push hl
@@ -598,9 +598,9 @@
 	ld a, BANK(LoadMenuMonIcon)
 	ld e, MONICON_PARTYMENU
 	rst FarCall
-	ldh a, [hObjectStructIndexBuffer]
+	ldh a, [hObjectStructIndex]
 	inc a
-	ldh [hObjectStructIndexBuffer], a
+	ldh [hObjectStructIndex], a
 	pop hl
 	pop bc
 	dec c
--- a/home/joypad.asm
+++ b/home/joypad.asm
@@ -346,14 +346,14 @@
 ;
 ; NOTE: The cursor has to be shown before calling
 ; this function or no cursor will be shown at all.
-	ldh a, [hMapObjectIndexBuffer]
+	ldh a, [hMapObjectIndex]
 	push af
-	ldh a, [hObjectStructIndexBuffer]
+	ldh a, [hObjectStructIndex]
 	push af
 	xor a
-	ldh [hMapObjectIndexBuffer], a
+	ldh [hMapObjectIndex], a
 	ld a, 6
-	ldh [hObjectStructIndexBuffer], a
+	ldh [hObjectStructIndex], a
 
 .loop
 	push hl
@@ -367,9 +367,9 @@
 	jr z, .loop
 
 	pop af
-	ldh [hObjectStructIndexBuffer], a
+	ldh [hObjectStructIndex], a
 	pop af
-	ldh [hMapObjectIndexBuffer], a
+	ldh [hMapObjectIndex], a
 	ret
 
 SimpleWaitPressAorB::
@@ -447,37 +447,37 @@
 	cp b
 	pop bc
 	jr nz, .place_arrow
-	ldh a, [hMapObjectIndexBuffer]
+	ldh a, [hMapObjectIndex]
 	dec a
-	ldh [hMapObjectIndexBuffer], a
+	ldh [hMapObjectIndex], a
 	ret nz
-	ldh a, [hObjectStructIndexBuffer]
+	ldh a, [hObjectStructIndex]
 	dec a
-	ldh [hObjectStructIndexBuffer], a
+	ldh [hObjectStructIndex], a
 	ret nz
 	ld a, "─"
 	ld [hl], a
 	ld a, -1
-	ldh [hMapObjectIndexBuffer], a
+	ldh [hMapObjectIndex], a
 	ld a, 6
-	ldh [hObjectStructIndexBuffer], a
+	ldh [hObjectStructIndex], a
 	ret
 
 .place_arrow
-	ldh a, [hMapObjectIndexBuffer]
+	ldh a, [hMapObjectIndex]
 	and a
 	ret z
 	dec a
-	ldh [hMapObjectIndexBuffer], a
+	ldh [hMapObjectIndex], a
 	ret nz
 	dec a
-	ldh [hMapObjectIndexBuffer], a
-	ldh a, [hObjectStructIndexBuffer]
+	ldh [hMapObjectIndex], a
+	ldh a, [hObjectStructIndex]
 	dec a
-	ldh [hObjectStructIndexBuffer], a
+	ldh [hObjectStructIndex], a
 	ret nz
 	ld a, 6
-	ldh [hObjectStructIndexBuffer], a
+	ldh [hObjectStructIndex], a
 	ld a, "▼"
 	ld [hl], a
 	ret
--- a/home/map.asm
+++ b/home/map.asm
@@ -1124,7 +1124,7 @@
 	text_end
 
 CheckObjectMask::
-	ldh a, [hMapObjectIndexBuffer]
+	ldh a, [hMapObjectIndex]
 	ld e, a
 	ld d, 0
 	ld hl, wObjectMasks
@@ -1133,7 +1133,7 @@
 	ret
 
 MaskObject::
-	ldh a, [hMapObjectIndexBuffer]
+	ldh a, [hMapObjectIndex]
 	ld e, a
 	ld d, 0
 	ld hl, wObjectMasks
@@ -1142,7 +1142,7 @@
 	ret
 
 UnmaskObject::
-	ldh a, [hMapObjectIndexBuffer]
+	ldh a, [hMapObjectIndex]
 	ld e, a
 	ld d, 0
 	ld hl, wObjectMasks
@@ -1433,7 +1433,7 @@
 	ld de, wScreenSave
 	ld a, [wMapWidth]
 	add 6
-	ldh [hMapObjectIndexBuffer], a
+	ldh [hMapObjectIndex], a
 	ld a, [wPlayerStepDirection]
 	and a
 	jr z, .down
@@ -1447,7 +1447,7 @@
 
 .up
 	ld de, wScreenSave + SCREEN_META_WIDTH
-	ldh a, [hMapObjectIndexBuffer]
+	ldh a, [hMapObjectIndex]
 	ld c, a
 	ld b, 0
 	add hl, bc
--- a/home/map_objects.asm
+++ b/home/map_objects.asm
@@ -20,7 +20,7 @@
 	ld hl, wUsedSprites + 2
 	ld c, SPRITE_GFX_LIST_CAPACITY - 1
 	ld b, a
-	ldh a, [hMapObjectIndexBuffer]
+	ldh a, [hMapObjectIndex]
 	cp 0
 	jr z, .nope
 	ld a, b
@@ -210,7 +210,7 @@
 
 CheckObjectVisibility::
 ; Sets carry if the object is not visible on the screen.
-	ldh [hMapObjectIndexBuffer], a
+	ldh [hMapObjectIndex], a
 	call GetMapObject
 	ld hl, MAPOBJECT_OBJECT_STRUCT_ID
 	add hl, bc
@@ -217,7 +217,7 @@
 	ld a, [hl]
 	cp -1
 	jr z, .not_visible
-	ldh [hObjectStructIndexBuffer], a
+	ldh [hObjectStructIndex], a
 	call GetObjectStruct
 	and a
 	ret
@@ -301,21 +301,21 @@
 	ret
 
 CopyMapObjectStruct:: ; unreferenced
-	ldh [hMapObjectIndexBuffer], a
+	ldh [hMapObjectIndex], a
 	call GetMapObject
 	call CopyObjectStruct
 	ret
 
 UnmaskCopyMapObjectStruct::
-	ldh [hMapObjectIndexBuffer], a
+	ldh [hMapObjectIndex], a
 	call UnmaskObject
-	ldh a, [hMapObjectIndexBuffer]
+	ldh a, [hMapObjectIndex]
 	call GetMapObject
 	farcall CopyObjectStruct
 	ret
 
 ApplyDeletionToMapObject::
-	ldh [hMapObjectIndexBuffer], a
+	ldh [hMapObjectIndex], a
 	call GetMapObject
 	ld hl, MAPOBJECT_OBJECT_STRUCT_ID
 	add hl, bc
--- a/hram.asm
+++ b/hram.asm
@@ -51,8 +51,8 @@
 hMoveMon:: db
 
 UNION
-hMapObjectIndexBuffer:: db
-hObjectStructIndexBuffer:: db
+hMapObjectIndex:: db
+hObjectStructIndex:: db
 NEXTU
 hConnectionStripLength:: db
 hConnectedMapWidth:: db
--- a/mobile/mobile_12_2.asm
+++ b/mobile/mobile_12_2.asm
@@ -422,15 +422,15 @@
 
 	ld c, a
 	xor a
-	ldh [hObjectStructIndexBuffer], a
+	ldh [hObjectStructIndex], a
 .loop
 	push bc
 	push hl
 	ld e, MONICON_PARTYMENU
 	farcall LoadMenuMonIcon
-	ldh a, [hObjectStructIndexBuffer]
+	ldh a, [hObjectStructIndex]
 	inc a
-	ldh [hObjectStructIndexBuffer], a
+	ldh [hObjectStructIndex], a
 	pop hl
 	pop bc
 	dec c
--- a/mobile/mobile_46.asm
+++ b/mobile/mobile_46.asm
@@ -5636,7 +5636,7 @@
 	ld a, [wMenuCursorY]
 	ld [wcd82], a
 	dec a
-	ldh [hObjectStructIndexBuffer], a
+	ldh [hObjectStructIndex], a
 	ld a, $10
 	ld [wCurIconTile], a
 	ld hl, LoadMenuMonIcon
--- a/engine/gfx/dma_transfer.asm
+++ b/engine/gfx/dma_transfer.asm
@@ -415,11 +415,11 @@
 
 PadMapForHDMATransfer:
 ; pad a 20x18 map to 32x18 for HDMA transfer
-; back up the padding value in c to hMapObjectIndexBuffer
-	ldh a, [hMapObjectIndexBuffer]
+; back up the padding value in c to hMapObjectIndex
+	ldh a, [hMapObjectIndex]
 	push af
 	ld a, c
-	ldh [hMapObjectIndexBuffer], a
+	ldh [hMapObjectIndex], a
 
 ; for each row on the screen
 	ld c, SCREEN_HEIGHT
@@ -435,7 +435,7 @@
 	jr nz, .loop2
 
 ; load the original padding value of c into hl for 32 - 20 = 12 rows
-	ldh a, [hMapObjectIndexBuffer]
+	ldh a, [hMapObjectIndex]
 	ld b, BG_MAP_WIDTH - SCREEN_WIDTH
 .loop3
 	ld [hli], a
@@ -445,9 +445,9 @@
 	dec c
 	jr nz, .loop1
 
 ; restore the original value of hMapObjectIndexBuffer
 	pop af
-	ldh [hMapObjectIndexBuffer], a
+	ldh [hMapObjectIndex], a
 	ret
 
 HDMATransfer2bpp::
@@ -445,9 +445,9 @@
 	jr nz, .loop1
 
-; restore the original value of hMapObjectIndexBuffer
+; restore the original value of hMapObjectIndex
 	pop af